<?php
/*
 * citeproc-php
 *
 * @link        http://github.com/seboettg/citeproc-php for the source repository
 * @copyright   Copyright (c) 2016 Sebastian Böttger.
 * @license     https://opensource.org/licenses/MIT
 */

namespace Seboettg\CiteProc\Test\Rendering;

use Exception;
use PHPUnit\Framework\TestCase;
use Seboettg\CiteProc\CiteProc;
use Seboettg\CiteProc\Context;
use Seboettg\CiteProc\Exception\InvalidStylesheetException;
use Seboettg\CiteProc\Locale\Locale;
use Seboettg\CiteProc\Rendering\Group;
use Seboettg\CiteProc\Test\TestSuiteTestCaseTrait;
use SimpleXMLElement;

class GroupTest extends TestCase
{
    use TestSuiteTestCaseTrait;

    private $data = "{\"title\":\"Ein Buch\", \"URL\":\"http://foo.bar\"}";

    public function setUp(): void
    {
        parent::setUp(); // TODO: Change the autogenerated stub
        $context = new Context();
        $context->setLocale(new Locale("de-DE"));
        CiteProc::setContext($context);
    }

    /**
     * @throws InvalidStylesheetException
     * @throws Exception
     */
    public function testRenderDelimiter()
    {
        $str = '<group delimiter=" "><text term="retrieved"/><text term="from"/><text variable="URL"/></group>';
        $group = new Group(new SimpleXMLElement($str), null);
        $this->assertEquals("abgerufen von http://foo.bar", $group->render(json_decode($this->data)));
    }

    /**
     * @throws InvalidStylesheetException
     * @throws Exception
     */
    public function testRenderAffixes()
    {
        $str = '<group prefix="[" suffix="]" delimiter=" "><text term="retrieved"/><text term="from"/><text variable="URL"/></group>';
        $group = new Group(new SimpleXMLElement($str), null);
        $this->assertEquals("[abgerufen von http://foo.bar]", $group->render(json_decode($this->data)));
    }

    /**
     * @throws InvalidStylesheetException
     * @throws Exception
     */
    public function testRenderDisplay()
    {
        $str = '<group display="indent" prefix="[" suffix="]" delimiter=" "><text term="retrieved"/><text term="from"/><text variable="URL"/></group>';
        $group = new Group(new SimpleXMLElement($str), null);
        $this->assertEquals("<div class=\"csl-indent\">[abgerufen von http://foo.bar]</div>", $group->render(json_decode($this->data)));
    }


    public function testGroupComplexNesting()
    {
        $this->runTestSuite("group_ComplexNesting");
    }

    public function testGroupShortOutputOnly()
    {
        $this->runTestSuite("group_ShortOutputOnly");
    }

    public function testGroupDelimiter()
    {
        $this->runTestSuite("group_Delimiter");
    }

    public function testSuppressTermWhenNoOutputFromPartialDate()
    {
        //TODO: implement
        $this->runTestSuite("group_SuppressTermWhenNoOutputFromPartialDate");
    }

    public function testGroupSuppressValueWithEmptySubgroup()
    {
        //TODO: implement
        $this->runTestSuite("group_SuppressValueWithEmptySubgroup");
    }

    /*
    public function testGroupSuppressWithEmptyNestedDateNode()
    {
        //TODO: implement
        $this->_testRenderTestSuite("group_SuppressWithEmptyNestedDateNode");
    }
    */
}
